@@ -7,25 +7,30 @@
 #ifndef PROJ4_H
 #define PROJ4_H
 
-#include <stdlib.h>
-#include "DgUtil.h"
+//#include "projUtil.h"
 /*
 #ifdef __cplusplus
 extern "C" {
 #endif
 */
 
-/* prototype hypot for systems where absent */
-
-extern long double usgs_hypot(long double, long double);
+#ifndef _proj4_constants_
+#define _proj4_constants_
 
 /* some useful constants */
 
-#define FORTPI     M_PI_4
-#define PI         M_PI
-#define TWOPI      6.28318530717958647692528676655900576L
-#define RAD_TO_DEG M_180_PI
-#define DEG_TO_RAD M_PI_180
+#define projM_PI_180   0.017453292519943295769236907684886L
+#define projM_PI_4     0.785398163397448309615660845819875721L
+#define projM_PI_2     1.570796326794896619231321691639751442L
+#define projM_PI       3.141592653589793238462643383279502884L
+#define projTWOPI      6.28318530717958647692528676655900576L
+
+#endif
+
+
+/* prototype hypot for systems where absent */
+
+extern long double usgs_hypot(long double, long double);
 
 typedef union { long double f; int i; char *s; } PVALUE;
 
